#!/bin/bash
# packager           : rederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# source location    : http://initd.org/tracker/pysqlite
# last revised       : 30/11/2009

softname='pysqlite'
softversion='2.5.6'
packageversion='64.1'

arch='i486'

# log ;)
(

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.gz"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://pysqlite.googlecode.com/files/$softname-$softversion.tar.gz

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/lib/python2.6/site-packages
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/src/$softname-$softversion

# put slack-desc in place
cat <<EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
pysqlite: DB-API 2.0 database interface for Python and SQLite
pysqlite:
pysqlite: pysqlite is a Python DB-API 2.0 interface for the SQLite
pysqlite: embedded relational database engine.
pysqlite: 
pysqlite:
pysqlite:
pysqlite:
pysqlite: 
pysqlite:
pysqlite:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar zxvf $srcpkg
cd $src

# packaging
python setup.py build
cp -a build/lib.linux-i686-2.6/pysqlite2 $dest/$prefix/lib/python2.6/site-packages
            
# add 'default' files
    cp -a \
      LICENSE PKG-INFO doc/* \
      $dest/usr/doc/$softname-$softversion
      
# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# put the ZenWalk build in the right directory
cp $buildir/build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "python,sqlite" > $package.dep

# generate source file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/l/pysqlite/source/build-pysqlite.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
